@@ -86,10 +86,10 @@ class Servico:
         return False if not json else "E" == json[0].get('status', False)
 
     def executado(self):
-        json = Controle.get().json()
-        for controle in json:
-            if controle['_id_servico'] == self.id:
-                return controle['executado']
+        response = Controle.get({'servico': self.id})
+        if response.ok and response.json():
+            return response.json()[0]['executado']
+        return False
 
 
 class Controle:
